==> 1.10.1.zip: entaxy-public/ui/entaxy-hawtio/entaxy-cicd-plugin/src/main/webapp/plugin/js/entaxyCICDHelpers.js <==
/*-
 * ~~~~~~licensing~~~~~~
 * entaxy-cicd-plugin
 * ==========
 * Copyright (C) 2020 - 2024 EmDev LLC
 * ==========
 * You may not use this file except in accordance with the License Terms of the Copyright
 * Holder located at: https://entaxy.ru/eula . All copyrights, all intellectual property
 * rights to the Software and any copies are the property of the Copyright Holder. Unless
 * it is explicitly allowed the Copyright Holder, the User is prohibited from using the
 * Software for commercial purposes to provide services to third parties.
 * 
 * The Copyright Holder hereby declares that the Software is provided on an "AS IS".
 * Under no circumstances does the Copyright Holder guarantee or promise that the
 * Software provided by him will be suitable or not suitable for the specific purposes
 * of the User, that the Software will meet all commercial and personal subjective
 * expectations of the User, that the Software will work properly, without technical
 * errors, quickly and uninterruptedly.
 * 
 * Under no circumstances shall the Copyright Holder or its Affiliates is not liable
 * to the User for any direct or indirect losses of the User, his expenses or actual
 * damage, including, downtime; loss of bussines; lost profit; lost earnings; loss
 * or damage to data, property, etc.
 * ~~~~~~/licensing~~~~~~
 */

var EntaxyCICD;
(function (EntaxyCICD) {

    const REVISION_STATUS = {
        CONFIGURED: 'CONFIGURED',
        DEPLOYED: 'DEPLOYED',
        INSTALLED: 'INSTALLED',
        UNINSTALLED: 'UNINSTALLED'
    }
    EntaxyCICD.REVISION_STATUS = REVISION_STATUS;

    const ITEM_TYPE = {
        APPLICATION: 'Application',
        PROJECT: 'Project',
        VERSION: 'Version'
    }
    EntaxyCICD.ITEM_TYPE = ITEM_TYPE;

    function isStorage(selection) {
        return selection.folderNames && selection.folderNames.length === 3;
    }
    EntaxyCICD.isStorage = isStorage;

    function getStorage(selection) {
        if (selection.folderNames) {
            switch (selection.folderNames.length) {
                case 3:
                    return selection.title;
                case 4:
                    return selection.parent.title;
                case 5:
                    return selection.parent.parent.title;
                case 6:
                    return selection.parent.parent.parent.title;
            }
        }
    }
    EntaxyCICD.getStorage = getStorage;

    function getStorages(selection) {
        return selection.children && selection.children.length > 0 ? selection.children.map(child => child.title) : [];
    }
    EntaxyCICD.getStorages = getStorages;

    function getProjectOrApplication(selection) {
        if (selection.folderNames) {
            switch (selection.folderNames.length) {
                case 4:
                    return selection.title;
                case 5:
                    return selection.parent.title;
                case 6:
                    return selection.parent.parent.title;
            }
        }
    }
    EntaxyCICD.getProjectOrApplication = getProjectOrApplication;

    function isVersion(selection) {
        return selection.folderNames && selection.folderNames.length === 5;
    }
    EntaxyCICD.isVersion = isVersion;

    function getVersion(selection) {
        if (selection.folderNames) {
            switch (selection.folderNames.length) {
                case 5:
                    return selection.title;
                case 6:
                    return selection.parent.title;
            }
        }
    }
    EntaxyCICD.getVersion = getVersion;

    function getVersions(selection) {
        return selection.children && selection.children.length > 0 ? selection.children.map(child => child.title) : [];
    }
    EntaxyCICD.getVersions = getVersions;

    function isRevision(selection) {
        return selection.folderNames && selection.folderNames.length === 6;
    }
    EntaxyCICD.isRevision = isRevision;

    function getRevisionInfo(selection) {
        let splitTitle = selection.title.split(' ');
        return {
            revision: splitTitle[0],
            revisionStatus: splitTitle[1].replace(/\[|]/g, '')
        };
    }
    EntaxyCICD.getRevisionInfo = getRevisionInfo;

    function getStatusTemplate(value) {
        if (value) {
            return '<span class="pficon pficon-ok"></span>'
        } else {
            return '<span class="pficon pficon-error-circle-o"></span>';
        }
    }
    EntaxyCICD.getStatusTemplate = getStatusTemplate;

    function capitalize(string) {
        return string.charAt(0).toUpperCase() + string.slice(1);
    }
    EntaxyCICD.capitalize = capitalize;

    function createTableFromUnremovedItems(unremovedItemsInfo) {
        let tableHtml = `<table class="entaxy-cicd-unremoved-info-table">`;
        tableHtml += `
            <tr>
                <th>Item</th>
                <th>Required By</th>
            </tr>
        `;
        Object.entries(unremovedItemsInfo).forEach(([itemId, listRequiredBy]) => {
            tableHtml += `<tr><td>` + itemId + `</td><td>`;
            listRequiredBy.forEach(requiredBy => {
                tableHtml += requiredBy + '\n';
            });
            tableHtml += `</td></tr>`;
        });
        tableHtml += `</table>`;
        return tableHtml;
    }
    EntaxyCICD.createTableFromUnremovedItems = createTableFromUnremovedItems;

    function createTableFromCopyConfigurationLocalValuesResult(result) {
        let tableHtml = `<table class="entaxy-result-table">`;
        tableHtml += `
            <tr>
                <th>Configuration Id</th>
                <th>Status</th>
            </tr>
        `;
        result.forEach(res => {
            let iconName = res.failed ? 'error-circle-o' : 'ok';
            tableHtml += `<tr><td style="padding-right: 5px;">` + res.id +
                `</td><td><span class="pficon pficon-${iconName}"></span></td></tr>`;
        });
        tableHtml += `</table>`;
        return tableHtml;
    }
    EntaxyCICD.createTableFromCopyConfigurationLocalValuesResult = createTableFromCopyConfigurationLocalValuesResult;

})(EntaxyCICD || (EntaxyCICD = {}));

==> 1.11.0.zip: entaxy-public/ui/entaxy-hawtio/entaxy-cicd-plugin/src/main/webapp/plugin/js/entaxyCICDHelpers.js <==
/*-
 * ~~~~~~licensing~~~~~~
 * entaxy-cicd-plugin
 * ==========
 * Copyright (C) 2020 - 2025 EmDev LLC
 * ==========
 * You may not use this file except in accordance with the License Terms of the Copyright
 * Holder located at: https://entaxy.ru/eula . All copyrights, all intellectual property
 * rights to the Software and any copies are the property of the Copyright Holder. Unless
 * it is explicitly allowed the Copyright Holder, the User is prohibited from using the
 * Software for commercial purposes to provide services to third parties.
 * 
 * The Copyright Holder hereby declares that the Software is provided on an "AS IS".
 * Under no circumstances does the Copyright Holder guarantee or promise that the
 * Software provided by him will be suitable or not suitable for the specific purposes
 * of the User, that the Software will meet all commercial and personal subjective
 * expectations of the User, that the Software will work properly, without technical
 * errors, quickly and uninterruptedly.
 * 
 * Under no circumstances shall the Copyright Holder or its Affiliates is not liable
 * to the User for any direct or indirect losses of the User, his expenses or actual
 * damage, including, downtime; loss of bussines; lost profit; lost earnings; loss
 * or damage to data, property, etc.
 * ~~~~~~/licensing~~~~~~
 */

var EntaxyCICD;
(function (EntaxyCICD) {

    const REVISION_STATUS = {
        CONFIGURED: 'CONFIGURED',
        DEPLOYED: 'DEPLOYED',
        INSTALLED: 'INSTALLED',
        UNINSTALLED: 'UNINSTALLED'
    }
    EntaxyCICD.REVISION_STATUS = REVISION_STATUS;

    const ITEM_TYPE = {
        APPLICATION: 'Application',
        PROJECT: 'Project',
        VERSION: 'Version'
    }
    EntaxyCICD.ITEM_TYPE = ITEM_TYPE;

    function isStorage(selection) {
        return selection.folderNames && selection.folderNames.length === 3;
    }
    EntaxyCICD.isStorage = isStorage;

    function getStorage(selection) {
        if (selection.folderNames) {
            switch (selection.folderNames.length) {
                case 3:
                    return selection.title;
                case 4:
                    return selection.parent.title;
                case 5:
                    return selection.parent.parent.title;
                case 6:
                    return selection.parent.parent.parent.title;
            }
        }
    }
    EntaxyCICD.getStorage = getStorage;

    function getStorages(selection) {
        return selection.children && selection.children.length > 0 ? selection.children.map(child => child.title) : [];
    }
    EntaxyCICD.getStorages = getStorages;

    function getProjectOrApplication(selection) {
        if (selection.folderNames) {
            switch (selection.folderNames.length) {
                case 4:
                    return selection.title;
                case 5:
                    return selection.parent.title;
                case 6:
                    return selection.parent.parent.title;
            }
        }
    }
    EntaxyCICD.getProjectOrApplication = getProjectOrApplication;

    function isVersion(selection) {
        return selection.folderNames && selection.folderNames.length === 5;
    }
    EntaxyCICD.isVersion = isVersion;

    function getVersion(selection) {
        if (selection.folderNames) {
            switch (selection.folderNames.length) {
                case 5:
                    return selection.title;
                case 6:
                    return selection.parent.title;
            }
        }
    }
    EntaxyCICD.getVersion = getVersion;

    function getVersions(selection) {
        return selection.children && selection.children.length > 0 ? selection.children.map(child => child.title) : [];
    }
    EntaxyCICD.getVersions = getVersions;

    function isRevision(selection) {
        return selection.folderNames && selection.folderNames.length === 6;
    }
    EntaxyCICD.isRevision = isRevision;

    function getRevisionInfo(selection) {
        let splitTitle = selection.title.split(' ');
        return {
            revision: splitTitle[0],
            revisionStatus: splitTitle[1].replace(/\[|]/g, '')
        };
    }
    EntaxyCICD.getRevisionInfo = getRevisionInfo;

    function getStatusTemplate(value) {
        if (value) {
            return '<span class="pficon pficon-ok"></span>'
        } else {
            return '<span class="pficon pficon-error-circle-o blue"></span>';
        }
    }
    EntaxyCICD.getStatusTemplate = getStatusTemplate;

    function capitalize(string) {
        return string.charAt(0).toUpperCase() + string.slice(1);
    }
    EntaxyCICD.capitalize = capitalize;

    function createTableFromUnremovedItems(unremovedItemsInfo) {
        let tableHtml = `<table class="entaxy-cicd-unremoved-info-table">`;
        tableHtml += `
            <tr>
                <th>Item</th>
                <th>Required By</th>
            </tr>
        `;
        Object.entries(unremovedItemsInfo).forEach(([itemId, listRequiredBy]) => {
            tableHtml += `<tr><td>` + itemId + `</td><td>`;
            listRequiredBy.forEach(requiredBy => {
                tableHtml += requiredBy + '\n';
            });
            tableHtml += `</td></tr>`;
        });
        tableHtml += `</table>`;
        return tableHtml;
    }
    EntaxyCICD.createTableFromUnremovedItems = createTableFromUnremovedItems;

})(EntaxyCICD || (EntaxyCICD = {}));
